@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,10 @@
 #include "semanage_core_login_process.h"
 #include "semanage_core_fcontext_process.h"
 #include "semanage_core_port_process.h"
+#include "semanage_core_translation_process.h"
+#include "semanage_core_boolean_process.h"
+#include "autorelabel.h"
+#include "policygeneration.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -94,6 +98,10 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	semanage_core_login_process_o = 0;
 	semanage_core_fcontext_process_o = 0;
 	semanage_core_port_process_o = 0;
+	semanage_core_translation_process_o = 0;
+	semanage_core_boolean_process_o = 0;
+	autorelabel_process_o = 0;
+	policygeneration_process_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -109,7 +117,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-4.50"));
+	setCaption(tr("segatex-5.00"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -414,20 +422,40 @@ void MainWindow::createActions()
 	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(semanage_core_process()));
 	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_login_processAct = new QAction(tr("&semanage login"), 0, this);
+	semanage_core_login_processAct = new QAction(tr("semanage l&ogin"), 0, this);
 	semanage_core_login_processAct->setStatusTip(tr("Semanage login -a -m -d."));
 	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(semanage_core_login_process()));
 	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_fcontext_processAct = new QAction(tr("&semanage fcontext"), 0, this);
+	semanage_core_fcontext_processAct = new QAction(tr("semanage &fcontext"), 0, this);
 	semanage_core_fcontext_processAct->setStatusTip(tr("Semanage fcontext -a -m -d."));
 	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(semanage_core_fcontext_process()));
 	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_port_processAct = new QAction(tr("&semanage port"), 0, this);
+	semanage_core_port_processAct = new QAction(tr("semanage &port"), 0, this);
 	semanage_core_port_processAct->setStatusTip(tr("Semanage port -a -m -d."));
 	connect(semanage_core_port_processAct, SIGNAL(activated()), this, SLOT(semanage_core_port_process()));
 	connect(semanage_core_port_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semanage_core_translation_processAct = new QAction(tr("semanage &translation"), 0, this);
+	semanage_core_translation_processAct->setStatusTip(tr("Semanage translation -a -m -d."));
+	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(semanage_core_translation_process()));
+	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semanage_core_boolean_processAct = new QAction(tr("setse&bool "), 0, this);
+	semanage_core_boolean_processAct->setStatusTip(tr("setsebool [-P] boolean value."));
+	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(semanage_core_boolean_process()));
+	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	autorelabel_processAct = new QAction(tr("auto&relabel "), 0, this);
+	autorelabel_processAct->setStatusTip(tr("autorelabel the system."));
+	connect(autorelabel_processAct, SIGNAL(activated()), this, SLOT(autorelabel_process()));
+	connect(autorelabel_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	policygeneration_processAct = new QAction(tr("Policy_&module "), 0, this);
+	policygeneration_processAct->setStatusTip(tr("Generate policy_module."));
+	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(policygeneration_process()));
+	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -500,12 +528,18 @@ void MainWindow::createMenus()
 
 	manageMenu = new QPopupMenu(this);
 	semodule_core_processAct->addTo(manageMenu);
+	policygeneration_processAct->addTo(manageMenu);
 
 	semanageMenu = new QPopupMenu(this);
 	semanage_core_processAct->addTo(semanageMenu);
 	semanage_core_login_processAct->addTo(semanageMenu);
 	semanage_core_fcontext_processAct->addTo(semanageMenu);
 	semanage_core_port_processAct->addTo(semanageMenu);
+	semanage_core_translation_processAct->addTo(semanageMenu);
+	semanage_core_boolean_processAct->addTo(semanageMenu);
+
+	autorelabelMenu = new QPopupMenu(this);
+	autorelabel_processAct->addTo(autorelabelMenu);
 
 	menuBar()->insertItem(tr("&File"), fileMenu);
 	menuBar()->insertItem(tr("&Edit"), editMenu);
@@ -522,6 +556,9 @@ void MainWindow::createMenus()
 	menuBar()->insertItem(tr("Selpa&w"), selpawMenu);
 	menuBar()->insertItem(tr("&Refine"), refineMenu);
 
+	menuBar()->insertSeparator();
+	menuBar()->insertItem(tr("Rel&abel"), autorelabelMenu);
+
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("&Help"), helpMenu);
 }
@@ -857,8 +894,8 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-4.50</h2>"
-		"<p>Copyright &copy; 2007"
+		tr("<h2>segatex-5.00</h2>"
+		"<p>Copyright &copy; 2007-2008"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex_suite is a SELinux tool"
 		"<p><b>written with Qt</b>."));
@@ -876,6 +913,9 @@ void MainWindow::howtouse()
 		" You can analize audit log."
 		" You can manage modules."
 		" You can semanage."
+		" You can setsebool."
+		" You can relabel the system."
+		" You can generate brand-new policy module."
 		" You can generate interfaced policy,by "
 		" Analize audit.log-generate policy."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
@@ -1072,3 +1112,39 @@ void MainWindow::semanage_core_port_process()
 	semanage_core_port_process_o->raise();
 	semanage_core_port_process_o->setActiveWindow();
 }
+void MainWindow::semanage_core_translation_process()
+{
+	if(!semanage_core_translation_process_o) {
+		semanage_core_translation_process_o = new SemanageCoreTranslationProcess(this);
+	}
+	semanage_core_translation_process_o->show();
+	semanage_core_translation_process_o->raise();
+	semanage_core_translation_process_o->setActiveWindow();
+}
+void MainWindow::semanage_core_boolean_process()
+{
+	if(!semanage_core_boolean_process_o) {
+		semanage_core_boolean_process_o = new SemanageCoreBooleanProcess(this);
+	}
+	semanage_core_boolean_process_o->show();
+	semanage_core_boolean_process_o->raise();
+	semanage_core_boolean_process_o->setActiveWindow();
+}
+void MainWindow::autorelabel_process()
+{
+	if(!autorelabel_process_o) {
+		autorelabel_process_o = new AutoRelabel(this);
+	}
+	autorelabel_process_o->show();
+	autorelabel_process_o->raise();
+	autorelabel_process_o->setActiveWindow();
+}
+void MainWindow::policygeneration_process()
+{
+	if(!policygeneration_process_o) {
+		policygeneration_process_o = new Policygeneration(this);
+	}
+	policygeneration_process_o->show();
+	policygeneration_process_o->raise();
+	policygeneration_process_o->setActiveWindow();
+}
