@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  * shintaro.fujiwara@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -54,6 +54,10 @@ class SemanageCoreProcess;
 class SemanageCoreLoginProcess;
 class SemanageCoreFcontextProcess;
 class SemanageCorePortProcess;
+class SemanageCoreTranslationProcess;
+class SemanageCoreBooleanProcess;
+class AutoRelabel;
+class Policygeneration;
 
 class MainWindow : public QMainWindow
 {
@@ -106,6 +110,10 @@ private slots:
     void semanage_core_login_process();
     void semanage_core_fcontext_process();
     void semanage_core_port_process();
+    void semanage_core_translation_process();
+    void semanage_core_boolean_process();
+    void autorelabel_process();
+    void policygeneration_process();
 
     void save();
     void saveAs();
@@ -172,6 +180,10 @@ private:
     SemanageCoreLoginProcess *semanage_core_login_process_o;
     SemanageCoreFcontextProcess *semanage_core_fcontext_process_o;
     SemanageCorePortProcess *semanage_core_port_process_o;
+    SemanageCoreTranslationProcess *semanage_core_translation_process_o;
+    SemanageCoreBooleanProcess *semanage_core_boolean_process_o;
+    AutoRelabel *autorelabel_process_o;
+    Policygeneration *policygeneration_process_o;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -184,6 +196,7 @@ private:
     QPopupMenu *policyMenu;
     QPopupMenu *manageMenu;
     QPopupMenu *semanageMenu;
+    QPopupMenu *autorelabelMenu;
 
     QToolBar *fileToolBar;
     QToolBar *editToolBar;
@@ -240,6 +253,10 @@ private:
     QAction *semanage_core_login_processAct;
     QAction *semanage_core_fcontext_processAct;
     QAction *semanage_core_port_processAct;
+    QAction *semanage_core_translation_processAct;
+    QAction *semanage_core_boolean_processAct;
+    QAction *autorelabel_processAct;
+    QAction *policygeneration_processAct;
 };
 
 #endif
