@@ -157,12 +157,14 @@ QRegExp rx_netutils_run_traceroute("netutils_run_traceroute");
 QRegExp rx_netutils_run_traceroute_cond("netutils_run_traceroute_cond");
 QRegExp rx_portage_run("portage_run");
 QRegExp rx_portage_run_gcc_config("portage_run_gcc_config");
+QRegExp rx_prelink_run("prelink_run");
 QRegExp rx_quota_run("quota_run");
 QRegExp rx_rpm_run("rpm_run");
 QRegExp rx_tripwire_run_tripwire("tripwire_run_tripwire");
 QRegExp rx_tripwire_run_twadmin("tripwire_run_twadmin");
 QRegExp rx_tripwire_run_twprint("tripwire_run_twprint");
 QRegExp rx_tripwire_run_siggen("tripwire_run_siggen");
+QRegExp rx_tzdata_run("tzdata_run");
 QRegExp rx_usbmodules_run("usbmodules_run");
 QRegExp rx_usermanage_run_chfn("usermanage_run_chfn");
 QRegExp rx_usermanage_run_groupadd("usermanage_run_groupadd");
@@ -191,6 +193,7 @@ QRegExp rx_cron_system_entry("cron_system_entry");
 QRegExp rx_dcc_run_cdcc("dcc_run_cdcc");
 QRegExp rx_dcc_run_client("dcc_run_client");
 QRegExp rx_dcc_run_dbclean("dcc_run_dbclean");
+QRegExp rx_ftp_run_ftpdctl("ftp_run_ftpdctl");
 QRegExp rx_inetd_core_service_domain("inetd_core_service_domain");
 QRegExp rx_inetd_tcp_service_domain("inetd_tcp_service_domain");
 QRegExp rx_inetd_udp_service_domain("inetd_udp_service_domain");
@@ -201,6 +204,7 @@ QRegExp rx_mta_sendmail_domtrans("mta_sendmail_domtrans");
 QRegExp rx_mta_spool_filetrans("mta_spool_filetrans");
 QRegExp rx_nscd_run("nscd_run");
 QRegExp rx_oav_run_update("oav_run_update");
+QRegExp rx_oddjob_system_entry("oddjob_system_entry");
 QRegExp rx_openvpn_run("openvpn_run");
 QRegExp rx_portmap_run_helper("portmap_run_helper");
 QRegExp rx_postfix_config_filetrans("postfix_config_filetrans");
@@ -211,6 +215,7 @@ QRegExp rx_qmail_smtpd_service_domain("qmail_smtpd_service_domain");
 QRegExp rx_rsync_entry_spec_domtrans("rsync_entry_spec_domtrans");
 QRegExp rx_rsync_entry_domtrans("rsync_entry_domtrans");
 QRegExp rx_samba_run_net("samba_run_net");
+QRegExp rx_samba_run_smbmount("samba_run_smbmount");
 QRegExp rx_samba_run_winbind_helper("samba_run_winbind_helper");
 QRegExp rx_tcpd_wrapped_domain("tcpd_wrapped_domain");
 QRegExp rx_ucspitcp_service_domain("ucspitcp_service_domain");
@@ -218,6 +223,8 @@ QRegExp rx_xserver_xsession_spec_domtrans("xserver_xsession_spec_domtrans");
 QRegExp rx_application_domain("application_domain");
 QRegExp rx_auth_domtrans_login_program("auth_domtrans_login_program");
 QRegExp rx_auth_ranged_domtrans_login_program("auth_ranged_domtrans_login_program");
+QRegExp rx_auth_run_chk_passwd("auth_run_chk_passwd");
+QRegExp rx_auth_run_upd_passwd("auth_run_upd_passwd");
 QRegExp rx_auth_run_pam("auth_run_pam");
 QRegExp rx_auth_read_all_dirs_except_shadow("auth_read_all_dirs_except_shadow");
 QRegExp rx_auth_read_all_files_except_shadow("auth_read_all_files_except_shadow");
@@ -427,12 +434,14 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_netutils_run_traceroute_cond, 0) != -1)||
 (line_analized.find( rx_portage_run, 0) != -1)||
 (line_analized.find( rx_portage_run_gcc_config, 0) != -1)||
+(line_analized.find( rx_prelink_run, 0) != -1)||
 (line_analized.find( rx_quota_run, 0) != -1)||
 (line_analized.find( rx_rpm_run, 0) != -1)||
 (line_analized.find( rx_tripwire_run_tripwire, 0) != -1)||
 (line_analized.find( rx_tripwire_run_twadmin, 0) != -1)||
 (line_analized.find( rx_tripwire_run_twprint, 0) != -1)||
 (line_analized.find( rx_tripwire_run_siggen, 0) != -1)||
+(line_analized.find( rx_tzdata_run, 0) != -1)||
 (line_analized.find( rx_usbmodules_run, 0) != -1)||
 (line_analized.find( rx_usermanage_run_chfn, 0) != -1)||
 (line_analized.find( rx_usermanage_run_groupadd, 0) != -1)||
@@ -461,6 +470,7 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_dcc_run_cdcc, 0) != -1)||
 (line_analized.find( rx_dcc_run_client, 0) != -1)||
 (line_analized.find( rx_dcc_run_dbclean, 0) != -1)||
+(line_analized.find( rx_ftp_run_ftpdctl, 0) != -1)||
 (line_analized.find( rx_inetd_core_service_domain, 0) != -1)||
 (line_analized.find( rx_inetd_tcp_service_domain, 0) != -1)||
 (line_analized.find( rx_inetd_udp_service_domain, 0) != -1)||
@@ -471,6 +481,7 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_mta_spool_filetrans, 0) != -1)||
 (line_analized.find( rx_nscd_run, 0) != -1)||
 (line_analized.find( rx_oav_run_update, 0) != -1)||
+(line_analized.find( rx_oddjob_system_entry, 0) != -1)||
 (line_analized.find( rx_openvpn_run, 0) != -1)||
 (line_analized.find( rx_portmap_run_helper, 0) != -1)||
 (line_analized.find( rx_postfix_config_filetrans, 0) != -1)||
@@ -481,6 +492,7 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_rsync_entry_spec_domtrans, 0) != -1)||
 (line_analized.find( rx_rsync_entry_domtrans, 0) != -1)||
 (line_analized.find( rx_samba_run_net, 0) != -1)||
+(line_analized.find( rx_samba_run_smbmount, 0) != -1)||
 (line_analized.find( rx_samba_run_winbind_helper, 0) != -1)||
 (line_analized.find( rx_tcpd_wrapped_domain, 0) != -1)||
 (line_analized.find( rx_ucspitcp_service_domain, 0) != -1)||
@@ -488,6 +500,8 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_application_domain, 0) != -1)||
 (line_analized.find( rx_auth_domtrans_login_program, 0) != -1)||
 (line_analized.find( rx_auth_ranged_domtrans_login_program, 0) != -1)||
+(line_analized.find( rx_auth_run_chk_passwd, 0) != -1)||
+(line_analized.find( rx_auth_run_upd_passwd, 0) != -1)||
 (line_analized.find( rx_auth_run_pam, 0) != -1)||
 (line_analized.find( rx_auth_read_all_dirs_except_shadow, 0) != -1)||
 (line_analized.find( rx_auth_read_all_files_except_shadow, 0) != -1)||
