@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include <qlayout.h>
 #include <qdir.h> 
 #include <qregexp.h> 
-//#include <qvaluevector.h> 
 #include <qlabel.h> 
 #include <qtextedit.h>
 
@@ -34,7 +33,6 @@ class QLayout;
 class QTextEdit;
 class QLineEdit;
 class QPushButton;
-class QProcess;
 
 class SemanageCoreFcontextProcess: public QDialog 
 {
@@ -100,7 +98,20 @@ private:
         QString semanageEditLineEdit3_str;
         QString semanageEditLineEdit4_str;
         QString semanageEditLineEdit5_str;
+	QString semanageEditLineEdit2_str_for_check;
+	QString semanageEditLineEdit3_str_for_check;
+	QString semanageEditLineEdit5_str_for_check;
         QString semanageEditLineEdit_str_pp;
+        QString semanageEditLineEdit_str_add_restorecon;
+        QString s_first;
+        QString s_first_for_restorecon_str;
+        QString s_second;
+        QString s_second_for_restorecon_str;
+        QString s_third;
+        QString s_third_for_restorecon_str;
+        QString s_fourth;
+        QString s_fourth_for_restorecon_str;
+        QString restorecon_str;
 };
 
 #endif
