@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include <qbuttongroup.h>
 #include <qlineedit.h>
 #include <qtextedit.h>
-#include <qprocess.h>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -34,7 +33,6 @@
 #include <fstream>
 
 #include "semanage_core_login_process.h"
-//#include "editor.h"
 
 #include <iostream>
 using namespace std;
@@ -47,18 +45,22 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	textEdit1->setPaletteBackgroundColor(QColor(0,254,100));
 
 	semanageEditLabel = new QLabel(tr("Add Unix user:"), this );
-	semanageEditLabel2 = new QLabel(tr("as a selinux user:"), this );
+	semanageEditLabel2 = new QLabel(tr("as a SELinux user:"), this );
+	semanageEditLabel6 = new QLabel(tr("range:"), this );
 	semanageEditLineEdit = new QLineEdit( this );
 	semanageEditLineEdit2 = new QLineEdit( this );
+	semanageEditLineEdit6 = new QLineEdit( this );
 	semanageEditLineEdit->setText("");
 	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
 	semanageEditLineEdit2->setText("");
 	semanageEditLineEdit2->setPaletteBackgroundColor(QColor(255,100,200));
+	semanageEditLineEdit6->setText("s0");
+	semanageEditLineEdit6->setPaletteBackgroundColor(QColor(255,100,200));
 	addButton = new QPushButton(tr("Add this user"), this);
 	addButton->setPaletteBackgroundColor(QColor(20,157,100));
 	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));
 
-	semanageEditLabel3 = new QLabel(tr("Delete Unix user's mapping to selinux user(Unix user's name):"), this );
+	semanageEditLabel3 = new QLabel(tr("Delete Unix user's mapping to SELinux user(Unix user's name):"), this );
 	semanageEditLineEdit3 = new QLineEdit( this );
 	semanageEditLineEdit3->setText("");
 	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
@@ -67,13 +69,17 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));
 
 	semanageEditLabel4 = new QLabel(tr("Modify Unix user:"), this );
-	semanageEditLabel5 = new QLabel(tr("as a selinux user:"), this );
+	semanageEditLabel5 = new QLabel(tr("as a SELinux user:"), this );
+	semanageEditLabel7 = new QLabel(tr("range:"), this );
 	semanageEditLineEdit4 = new QLineEdit( this );
 	semanageEditLineEdit5 = new QLineEdit( this );
+	semanageEditLineEdit7 = new QLineEdit( this );
 	semanageEditLineEdit4->setText("");
 	semanageEditLineEdit4->setPaletteBackgroundColor(QColor(255,100,200));
 	semanageEditLineEdit5->setText("");
 	semanageEditLineEdit5->setPaletteBackgroundColor(QColor(255,100,200));
+	semanageEditLineEdit7->setText("s0");
+	semanageEditLineEdit7->setPaletteBackgroundColor(QColor(255,100,200));
 	modifyButton = new QPushButton(tr("Modify this user"), this);
 	modifyButton->setPaletteBackgroundColor(QColor(20,157,100));
 	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));
@@ -101,6 +107,8 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	leftLayout->addWidget(semanageEditLineEdit);
 	leftLayout->addWidget(semanageEditLabel2);
 	leftLayout->addWidget(semanageEditLineEdit2);
+	leftLayout->addWidget(semanageEditLabel6);
+	leftLayout->addWidget(semanageEditLineEdit6);
 	leftLayout->addWidget(addButton);
 	rightLayout->addWidget(semanageEditLabel3);
 	rightLayout->addWidget(semanageEditLineEdit3);
@@ -109,6 +117,8 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	thirdLayout->addWidget(semanageEditLineEdit4);
 	thirdLayout->addWidget(semanageEditLabel5);
 	thirdLayout->addWidget(semanageEditLineEdit5);
+	thirdLayout->addWidget(semanageEditLabel7);
+	thirdLayout->addWidget(semanageEditLineEdit7);
 	thirdLayout->addWidget(modifyButton);
 
 	middleLayout->addLayout(leftLayout);
@@ -130,7 +140,8 @@ void SemanageCoreLoginProcess::add_button_clicked()
 {
 	semanageEditLineEdit_str = semanageEditLineEdit->text();
 	semanageEditLineEdit2_str = semanageEditLineEdit2->text();
-	add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str);
+	semanageEditLineEdit6_str = semanageEditLineEdit6->text();
+	add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str,semanageEditLineEdit6_str);
 }
 /*signal and slot should have same argument pattern so I had to pass to another slot*/
 void SemanageCoreLoginProcess::delete_button_clicked()
@@ -143,13 +154,13 @@ void SemanageCoreLoginProcess::modify_button_clicked()
 {
 	semanageEditLineEdit4_str = semanageEditLineEdit4->text();
 	semanageEditLineEdit5_str = semanageEditLineEdit5->text();
-	modify_button_clicked_process(semanageEditLineEdit4_str,semanageEditLineEdit5_str);
+	semanageEditLineEdit7_str = semanageEditLineEdit7->text();
+	modify_button_clicked_process(semanageEditLineEdit4_str,semanageEditLineEdit5_str,semanageEditLineEdit7_str);
 }
-/* this slot does just make .pp file */
-void SemanageCoreLoginProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str)
+
+void SemanageCoreLoginProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str, QString semanageEditLineEdit6_str)
 {
-	//semanageEditLineEdit_str_pp = "cd /root/segatex;make -f /usr/share/selinux/devel/Makefile " + semanageEditLineEdit_str + ".pp";
-	semanageEditLineEdit_str_pp = "semanage login -a -s " + semanageEditLineEdit2_str + " " + semanageEditLineEdit_str;
+	semanageEditLineEdit_str_pp = "semanage login -a -s " + semanageEditLineEdit2_str + " -r " + semanageEditLineEdit6_str + " " + semanageEditLineEdit_str;
         #define PWD_BUF 8600
         const char* make_module_file="/root/segatex/semanage/add_loggedin";
         ofstream os_add;
@@ -177,7 +188,7 @@ void SemanageCoreLoginProcess::add_button_clicked_process(QString semanageEditLi
 	semanage_core_base_login_process();
 	//outputfile_str_common2 = make_module_file;
 }
-/* this slot does just make .pp file */
+
 void SemanageCoreLoginProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str)
 {
 	semanageEditLineEdit_str_pp = "semanage login -d " + semanageEditLineEdit3_str;
@@ -206,12 +217,11 @@ void SemanageCoreLoginProcess::delete_button_clicked_process(QString semanageEdi
 	os_delete.close();
 	//set textEdit semanage -l
 	semanage_core_base_login_process();
-	//outputfile_str_common2 = make_module_file;
 }
-/* this slot does just make .pp file */
-void SemanageCoreLoginProcess::modify_button_clicked_process(QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str)
+
+void SemanageCoreLoginProcess::modify_button_clicked_process(QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str, QString semanageEditLineEdit7_str)
 {
-	semanageEditLineEdit_str_pp = "semanage login -m -s " + semanageEditLineEdit5_str + " " + semanageEditLineEdit4_str;
+	semanageEditLineEdit_str_pp = "semanage login -m -s " + semanageEditLineEdit5_str + " -r " + semanageEditLineEdit7_str + " " + semanageEditLineEdit4_str;
         #define PWD_BUF 8600
         const char* make_module_file="/root/segatex/semanage/modify_loggedin";
         ofstream os_modify;
