@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include <qlayout.h>
 #include <qdir.h> 
 #include <qregexp.h> 
-//#include <qvaluevector.h> 
 #include <qlabel.h> 
 #include <qtextedit.h>
 
@@ -34,7 +33,6 @@ class QLayout;
 class QTextEdit;
 class QLineEdit;
 class QPushButton;
-class QProcess;
 
 class SemanageCoreLoginProcess: public QDialog 
 {
@@ -51,9 +49,9 @@ private slots:
 	void add_button_clicked();
 	void delete_button_clicked();
 	void modify_button_clicked();
-	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
+	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str, QString textEdit6_str);
 	void delete_button_clicked_process(QString textEdit3_str);
-	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str);
+	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str, QString textEdit7_str);
 	void readFromOutputFile();
 public:
 private:
@@ -93,16 +91,22 @@ private:
         QLabel *semanageEditLabel3;
         QLabel *semanageEditLabel4;
         QLabel *semanageEditLabel5;
+        QLabel *semanageEditLabel6;
+        QLabel *semanageEditLabel7;
         QLineEdit *semanageEditLineEdit;
         QLineEdit *semanageEditLineEdit2;
         QLineEdit *semanageEditLineEdit3;
         QLineEdit *semanageEditLineEdit4;
         QLineEdit *semanageEditLineEdit5;
+        QLineEdit *semanageEditLineEdit6;
+        QLineEdit *semanageEditLineEdit7;
         QString semanageEditLineEdit_str;
         QString semanageEditLineEdit2_str;
         QString semanageEditLineEdit3_str;
         QString semanageEditLineEdit4_str;
         QString semanageEditLineEdit5_str;
+        QString semanageEditLineEdit6_str;
+        QString semanageEditLineEdit7_str;
         QString semanageEditLineEdit_str_pp;
 };
 
